==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/outputs/GalleryApplicationVersionPublishingProfileResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.outputs

import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 * The publishing profile of a gallery image version.
 * @property advancedSettings Optional. Additional settings to pass to the vm-application-manager extension. For advanced use only.
 * @property customActions A list of custom actions that can be performed with this Gallery Application Version.
 * @property enableHealthCheck Optional. Whether or not this application reports health.
 * @property endOfLifeDate The end of life date of the gallery image version. This property can be used for decommissioning purposes. This property is updatable.
 * @property excludeFromLatest If set to true, Virtual Machines deployed from the latest version of the Image Definition won't use this Image Version.
 * @property manageActions
 * @property publishedDate The timestamp for when the gallery image version is published.
 * @property replicaCount The number of replicas of the Image Version to be created per region. This property would take effect for a region when regionalReplicaCount is not specified. This property is updatable.
 * @property replicationMode Optional parameter which specifies the mode to be used for replication. This property is not updatable.
 * @property settings Additional settings for the VM app that contains the target package and config file name when it is deployed to target VM or VM scale set.
 * @property source The source image from which the Image Version is going to be created.
 * @property storageAccountType Specifies the storage account type to be used to store the image. This property is not updatable.
 * @property targetExtendedLocations The target extended locations where the Image Version is going to be replicated to. This property is updatable.
 * @property targetRegions The target regions where the Image Version is going to be replicated to. This property is updatable.
 */
public data class GalleryApplicationVersionPublishingProfileResponse(
    public val advancedSettings: Map<String, String>? = null,
    public val customActions: List<GalleryApplicationCustomActionResponse>? = null,
    public val enableHealthCheck: Boolean? = null,
    public val endOfLifeDate: String? = null,
    public val excludeFromLatest: Boolean? = null,
    public val manageActions: UserArtifactManageResponse? = null,
    public val publishedDate: String,
    public val replicaCount: Int? = null,
    public val replicationMode: String? = null,
    public val settings: UserArtifactSettingsResponse? = null,
    public val source: UserArtifactSourceResponse,
    public val storageAccountType: String? = null,
    public val targetExtendedLocations: List<GalleryTargetExtendedLocationResponse>? = null,
    public val targetRegions: List<TargetRegionResponse>? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.compute.outputs.GalleryApplicationVersionPublishingProfileResponse):
            GalleryApplicationVersionPublishingProfileResponse =
            GalleryApplicationVersionPublishingProfileResponse(
                advancedSettings = javaType.advancedSettings().map({ args0 -> args0.key.to(args0.value) }).toMap(),
                customActions = javaType.customActions().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.GalleryApplicationCustomActionResponse.Companion.toKotlin(args0)
                    })
                }),
                enableHealthCheck = javaType.enableHealthCheck().map({ args0 -> args0 }).orElse(null),
                endOfLifeDate = javaType.endOfLifeDate().map({ args0 -> args0 }).orElse(null),
                excludeFromLatest = javaType.excludeFromLatest().map({ args0 -> args0 }).orElse(null),
                manageActions = javaType.manageActions().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.UserArtifactManageResponse.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                publishedDate = javaType.publishedDate(),
                replicaCount = javaType.replicaCount().map({ args0 -> args0 }).orElse(null),
                replicationMode = javaType.replicationMode().map({ args0 -> args0 }).orElse(null),
                settings = javaType.settings().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.UserArtifactSettingsResponse.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                source = javaType.source().let({ args0 ->
                    com.pulumi.azurenative.compute.kotlin.outputs.UserArtifactSourceResponse.Companion.toKotlin(args0)
                }),
                storageAccountType = javaType.storageAccountType().map({ args0 -> args0 }).orElse(null),
                targetExtendedLocations = javaType.targetExtendedLocations().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.GalleryTargetExtendedLocationResponse.Companion.toKotlin(args0)
                    })
                }),
                targetRegions = javaType.targetRegions().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.TargetRegionResponse.Companion.toKotlin(args0)
                    })
                }),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/compute/kotlin/outputs/GalleryApplicationVersionPublishingProfileResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.outputs

import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 * The publishing profile of a gallery image version.
 * @property advancedSettings Optional. Additional settings to pass to the vm-application-manager extension. For advanced use only.
 * @property customActions A list of custom actions that can be performed with this Gallery Application Version.
 * @property enableHealthCheck Optional. Whether or not this application reports health.
 * @property endOfLifeDate The end of life date of the gallery image version. This property can be used for decommissioning purposes. This property is updatable.
 * @property excludeFromLatest If set to true, Virtual Machines deployed from the latest version of the Image Definition won't use this Image Version.
 * @property manageActions
 * @property publishedDate The timestamp for when the gallery image version is published.
 * @property replicaCount The number of replicas of the Image Version to be created per region. This property would take effect for a region when regionalReplicaCount is not specified. This property is updatable.
 * @property replicationMode Optional parameter which specifies the mode to be used for replication. This property is not updatable.
 * @property settings Additional settings for the VM app that contains the target package and config file name when it is deployed to target VM or VM scale set.
 * @property source The source image from which the Image Version is going to be created.
 * @property storageAccountType Specifies the storage account type to be used to store the image. This property is not updatable.
 * @property targetExtendedLocations The target extended locations where the Image Version is going to be replicated to. This property is updatable.
 * @property targetRegions The target regions where the Image Version is going to be replicated to. This property is updatable.
 */
public data class GalleryApplicationVersionPublishingProfileResponse(
    public val advancedSettings: Map<String, String>? = null,
    public val customActions: List<GalleryApplicationCustomActionResponse>? = null,
    public val enableHealthCheck: Boolean? = null,
    public val endOfLifeDate: String? = null,
    public val excludeFromLatest: Boolean? = null,
    public val manageActions: UserArtifactManageResponse? = null,
    public val publishedDate: String,
    public val replicaCount: Int? = null,
    public val replicationMode: String? = null,
    public val settings: UserArtifactSettingsResponse? = null,
    public val source: UserArtifactSourceResponse,
    public val storageAccountType: String? = null,
    public val targetExtendedLocations: List<GalleryTargetExtendedLocationResponse>? = null,
    public val targetRegions: List<TargetRegionResponse>? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.compute.outputs.GalleryApplicationVersionPublishingProfileResponse): GalleryApplicationVersionPublishingProfileResponse =
            GalleryApplicationVersionPublishingProfileResponse(
                advancedSettings = javaType.advancedSettings().map({ args0 -> args0.key.to(args0.value) }).toMap(),
                customActions = javaType.customActions().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.GalleryApplicationCustomActionResponse.Companion.toKotlin(args0)
                    })
                }),
                enableHealthCheck = javaType.enableHealthCheck().map({ args0 -> args0 }).orElse(null),
                endOfLifeDate = javaType.endOfLifeDate().map({ args0 -> args0 }).orElse(null),
                excludeFromLatest = javaType.excludeFromLatest().map({ args0 -> args0 }).orElse(null),
                manageActions = javaType.manageActions().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.UserArtifactManageResponse.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                publishedDate = javaType.publishedDate(),
                replicaCount = javaType.replicaCount().map({ args0 -> args0 }).orElse(null),
                replicationMode = javaType.replicationMode().map({ args0 -> args0 }).orElse(null),
                settings = javaType.settings().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.UserArtifactSettingsResponse.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                source = javaType.source().let({ args0 ->
                    com.pulumi.azurenative.compute.kotlin.outputs.UserArtifactSourceResponse.Companion.toKotlin(args0)
                }),
                storageAccountType = javaType.storageAccountType().map({ args0 -> args0 }).orElse(null),
                targetExtendedLocations = javaType.targetExtendedLocations().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.GalleryTargetExtendedLocationResponse.Companion.toKotlin(args0)
                    })
                }),
                targetRegions = javaType.targetRegions().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.TargetRegionResponse.Companion.toKotlin(args0)
                    })
                }),
            )
    }
}
